/*
 * arch/i386/include/klibc/archsetjmp.h
 */

#ifndef _KLIBC_ARCHSETJMP_H
#define _KLIBC_ARCHSETJMP_H

struct __jmp_buf {
    unsigned int __ebx;
    unsigned int __esp;
    unsigned int __ebp;
    unsigned int __esi;
    unsigned int __edi;
    unsigned int __eip;
};

typedef struct __jmp_buf jmp_buf[1];

#endif /* _SETJMP_H */
